@@ -1,23 +1,5 @@
 use strict;
 
-package Tangram::DataCursor;
-
-sub new
-{
-   my $pkg = shift;
-   return bless [ @_ ] , $pkg;
-}
-
-sub execute
-{
-   my ($self, $storage) = @_;
-   my ($obj, $table, $col, $id) = @$self;
-	my $obj_id = $storage->id($obj);
-   my $sql = "UPDATE $table SET $col = $obj_id WHERE $table.id = $id";
-   $storage->sql_do($sql);
-}
-
-
 package Tangram::Cursor;
 
 use vars qw( $stored %done );
@@ -330,4 +312,10 @@ sub fetchrow
 	map { $_->{type}->read_data(\@row) } @{$self->{select}{cols}};
 }
 
+sub new
+{
+   my $pkg = shift;
+   return bless [ @_ ] , $pkg;
+}
+
 1;
\ No newline at end of file
